==> jc-1.4.0.tar.gz: soot/grimp/internal/GCastExpr.h <==
// public class soot.grimp.internal.GCastExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46174ec987c28ee2 soot_grimp_internal_GCastExpr
// @dep_class f314930900c2c411 soot_jimple_internal_AbstractCastExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractCastExpr

#include "soot/jimple/internal/AbstractCastExpr.h"

#ifndef _JC_soot_grimp_internal_GCastExpr_H_
#define _JC_soot_grimp_internal_GCastExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GCastExpr$sub_refs	_jc_soot_grimp_internal_GCastExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GCastExpr$sub_nonrefs	_jc_soot_grimp_internal_GCastExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GCastExpr$refs	_jc_soot_grimp_internal_GCastExpr$refs;
typedef struct _jc_soot_grimp_internal_GCastExpr$nonrefs	_jc_soot_grimp_internal_GCastExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GCastExpr$object	_jc_soot_grimp_internal_GCastExpr$object;

typedef const struct _jc_soot_grimp_internal_GCastExpr$vmethods	_jc_soot_grimp_internal_GCastExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GCastExpr$vtable	_jc_soot_grimp_internal_GCastExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GCastExpr$vtype	_jc_soot_grimp_internal_GCastExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GCastExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GCastExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
extern jint _jc_soot_grimp_internal_GCastExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GCastExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GCastExpr$method$toString$d5ff0f7db9adef4f(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$toString$d5ff0f7db9adef4f;

// Virtual methods structure
struct _jc_soot_grimp_internal_GCastExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$d5ff0f7db9adef4f)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GCastExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractCastExpr$vmethods	soot_jimple_internal_AbstractCastExpr;
	_jc_soot_grimp_internal_GCastExpr$vmethods	soot_grimp_internal_GCastExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GCastExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GCastExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GCastExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GCastExpr$refs {
    _jc_soot_grimp_internal_GCastExpr$sub_refs	soot_grimp_internal_GCastExpr;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_refs	soot_jimple_internal_AbstractCastExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GCastExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GCastExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_nonrefs	soot_jimple_internal_AbstractCastExpr;
    _jc_soot_grimp_internal_GCastExpr$sub_nonrefs	soot_grimp_internal_GCastExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GCastExpr$object {
	_jc_soot_grimp_internal_GCastExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GCastExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GCastExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GCastExpr$vtype _jc_soot_grimp_internal_GCastExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GCastExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GCastExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GCastExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GCastExpr.h <==
// public class soot.grimp.internal.GCastExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 46174ec987c28ee2 soot_grimp_internal_GCastExpr
// @dep_class f314930900c2c411 soot_jimple_internal_AbstractCastExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractCastExpr

#include "soot/jimple/internal/AbstractCastExpr.h"

#ifndef _JC_soot_grimp_internal_GCastExpr_H_
#define _JC_soot_grimp_internal_GCastExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GCastExpr$sub_refs	_jc_soot_grimp_internal_GCastExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GCastExpr$sub_nonrefs	_jc_soot_grimp_internal_GCastExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GCastExpr$refs	_jc_soot_grimp_internal_GCastExpr$refs;
typedef struct _jc_soot_grimp_internal_GCastExpr$nonrefs	_jc_soot_grimp_internal_GCastExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GCastExpr$object	_jc_soot_grimp_internal_GCastExpr$object;

typedef const struct _jc_soot_grimp_internal_GCastExpr$vmethods	_jc_soot_grimp_internal_GCastExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GCastExpr$vtable	_jc_soot_grimp_internal_GCastExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GCastExpr$vtype	_jc_soot_grimp_internal_GCastExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GCastExpr$method$_init$743c179cbcd16e16(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GCastExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GCastExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GCastExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GCastExpr$method$toString$d5ff0f7db9adef4f(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_grimp_internal_GCastExpr$method_info$toString$d5ff0f7db9adef4f;

// Virtual methods structure
struct _jc_soot_grimp_internal_GCastExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$d5ff0f7db9adef4f)(_jc_env *, struct _jc_soot_grimp_internal_GCastExpr$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GCastExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractCastExpr$vmethods	soot_jimple_internal_AbstractCastExpr;
	_jc_soot_grimp_internal_GCastExpr$vmethods	soot_grimp_internal_GCastExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GCastExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GCastExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GCastExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GCastExpr$refs {
    _jc_soot_grimp_internal_GCastExpr$sub_refs	soot_grimp_internal_GCastExpr;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_refs	soot_jimple_internal_AbstractCastExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GCastExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GCastExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractCastExpr$sub_nonrefs	soot_jimple_internal_AbstractCastExpr;
    _jc_soot_grimp_internal_GCastExpr$sub_nonrefs	soot_grimp_internal_GCastExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GCastExpr$object {
	_jc_soot_grimp_internal_GCastExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GCastExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GCastExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GCastExpr$vtype _jc_soot_grimp_internal_GCastExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GCastExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GCastExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GCastExpr_H_ */
